@@ -1,6 +1,6 @@
 # PiTiVi , Non-linear video editor
 #
-#       ui/configure.py
+#       configure.py
 #
 # Copyright (c) 2005, Edward Hervey <bilboed@bilboed.com>
 #
@@ -24,35 +24,40 @@ Enables identical use for installed and uninstalled versions.
 """
 
 import os.path
-import string
 
-LIBDIR = '/usr/lib'
-PKGDATADIR = '/usr/share/pitivi'
-PIXMAPDIR = '/usr/share/pixmaps'
-pitivi_version = '0.11.1'
+LIBDIR = '/usr/local/lib'
+PKGDATADIR = '/usr/local/share/pitivi'
+PIXMAPDIR = '/usr/local/share/pixmaps'
+pitivi_version = '0.11.2.2'
 APPNAME = 'PiTiVi'
 PYGTK_REQ = '2.8.0'
 PYGST_REQ = '0.10.6'
 GST_REQ = '0.10.13.1'
-GNONLIN_REQ = '0.10.8.1'
+GNONLIN_REQ = '0.10.10'
 PYCAIRO_REQ = '1.0.0'
 
+def _get_root_dir():
+    return '/'.join(os.path.dirname(os.path.abspath(__file__)).split('/')[:-1])
+
+def _in_devel():
+    rd = _get_root_dir()
+    return (os.path.exists(os.path.join(rd, '.svn')) or
+            os.path.exists(os.path.join(rd, 'CVS')) or
+            os.path.exists(os.path.join(rd, '.git')))
+
 def get_pixmap_dir():
     """ Returns the directory for program-only pixmaps """
-    dir = os.path.dirname(os.path.abspath(__file__))
-    if (os.path.exists(os.path.join(dir, 'CVS')) or
-        os.path.exists(os.path.join(dir, '.svn'))):
-        root = dir
+    _dir = os.path.dirname(os.path.abspath(__file__))
+    if _in_devel():
+        root = _dir
     else:
         root = PKGDATADIR
     return os.path.join(root, 'pixmaps')
 
 def get_global_pixmap_dir():
     """ Returns the directory for global pixmaps (ex : application icon) """
-    dir = os.path.dirname(os.path.abspath(__file__))
-    if (os.path.exists(os.path.join(dir, 'CVS')) or
-        os.path.exists(os.path.join(dir, '.svn'))):
-        root = string.join(dir.split('/')[:-1], '/')
+    if _in_devel():
+        root = _get_root_dir()
     else:
         root = PIXMAPDIR
     return root
