@@ -28,10 +28,11 @@ import gobject
 import gst
 from bin import SmartBin, SmartDefaultBin, SmartFileBin, SmartTimelineBin
 from utils import bin_contains
+from signalinterface import Signallable
 
 from gettext import gettext as _
 
-class PlayGround(gobject.GObject):
+class PlayGround(object, Signallable):
     """
     Holds all the applications pipelines.
     Multimedia sinks can be shared amongst the various pipelines, to offer
@@ -51,33 +52,19 @@ class PlayGround(gobject.GObject):
       element-message : messages received of type gst.MESSAGE_ELEMENT
     """
 
-    __gsignals__ = {
-        "current-changed" : ( gobject.SIGNAL_RUN_LAST,
-                              gobject.TYPE_NONE,
-                              (gobject.TYPE_PYOBJECT, )),
-        "current-state" : ( gobject.SIGNAL_RUN_LAST,
-                            gobject.TYPE_NONE,
-                            (gobject.TYPE_PYOBJECT, )),
-        "bin-added" : ( gobject.SIGNAL_RUN_LAST,
-                       gobject.TYPE_NONE,
-                       ( gobject.TYPE_PYOBJECT, )),
-        "bin-removed" : ( gobject.SIGNAL_RUN_LAST,
-                          gobject.TYPE_NONE,
-                          ( gobject.TYPE_PYOBJECT, )),
-        "error" : ( gobject.SIGNAL_RUN_LAST,
-                    gobject.TYPE_NONE,
-                    ( gobject.TYPE_STRING, gobject.TYPE_STRING )),
-        "position" : ( gobject.SIGNAL_RUN_LAST,
-                       gobject.TYPE_NONE,
-                       ( gobject.TYPE_PYOBJECT, gobject.TYPE_UINT64 )),
-        "element-message" : ( gobject.SIGNAL_RUN_LAST,
-                              gobject.TYPE_NONE,
-                              ( gst.Message, ))
+    __signals__ = {
+        "current-changed" : ["smartbin"],
+        "current-state" : ["smartbin"],
+        "bin-added" : ["smartbin"],
+        "bin-removed" : ["smartbin"],
+        "error" : ["string1", "string2"],
+        "position" : ["bin", "position"],
+        "element-message" : ["message"]
         }
 
     def __init__(self):
         gst.log("Starting up playground")
-        gobject.GObject.__init__(self)
+
         # List of used pipelines
         self.pipelines = []
 
@@ -141,7 +128,7 @@ class PlayGround(gobject.GObject):
 
         bus = pipeline.get_bus()
         bus.remove_signal_watch()
-        bus.set_sync_handler(None)
+        #bus.set_sync_handler(None)
 
         if pipeline.set_state(gst.STATE_READY) == gst.STATE_CHANGE_FAILURE:
             return False
@@ -206,13 +193,21 @@ class PlayGround(gobject.GObject):
         will be taken.
         """
         if isinstance(self.current, SmartTimelineBin):
-            # fast path
             return True
+        tl = self.getTimeline()
+        if tl:
+            self.switchToPipeline(tl)
+            return True
+        return False
+
+    def getTimeline(self):
+        """
+        Returns the Timeline if any is present in the playground
+        """
         for pipeline in self.pipelines:
             if isinstance(pipeline, SmartTimelineBin):
-                self.switchToPipeline(pipeline)
-                return True
-        return False
+                return pipeline
+        return None
 
     def setVideoSinkThread(self, vsinkthread):
         """ sets the video sink thread """
@@ -281,7 +276,7 @@ class PlayGround(gobject.GObject):
         # actually being displayed currently :(
         try:
             if onlyvideo and not self.current.recording:
-                cur,format = self.vsinkthread.query_position(gst.FORMAT_TIME)
+                cur, format = self.vsinkthread.query_position(gst.FORMAT_TIME)
             else:
                 cur, format = self.current.query_position(gst.FORMAT_TIME)
         except:
@@ -315,7 +310,7 @@ class PlayGround(gobject.GObject):
                           gst.SEEK_TYPE_SET, value,
                           gst.SEEK_TYPE_NONE, -1)
         if not res:
-            gst.warning ("Seeking in current failed !");
+            gst.warning ("Seeking in current failed !")
             return False
         gst.debug("Seeking to %s succeeded" % gst.TIME_ARGS (value))
 
