@@ -25,8 +25,8 @@ Project class
 """
 
 import os.path
-import gobject
 import gst
+import traceback
 from timeline.timeline import Timeline
 from sourcelist import SourceList
 from bin import SmartTimelineBin
@@ -34,13 +34,14 @@ from settings import ExportSettings
 from configure import APPNAME
 from gettext import gettext as _
 from serializable import Serializable, to_object_from_data_type
-from projectsaver import ProjectSaver, ProjectSaveError, ProjectLoadError
+from projectsaver import ProjectSaver, ProjectLoadError
+from signalinterface import Signallable
 
-class Project(gobject.GObject, Serializable):
+class Project(Serializable, Signallable):
     """ The base class for PiTiVi projects
     Signals
 
-       string save-uri-requested()
+       boolean save-uri-requested()
             The the current project has been requested to save itself, but
             needs a URI to which to save. Handlers should first call
             setUri(), with the uri to save the file (optionally
@@ -59,16 +60,10 @@ class Project(gobject.GObject, Serializable):
             The project settings have changed
     """
 
-    __gsignals__ = {
-        "save-uri-requested" : ( gobject.SIGNAL_RUN_LAST,
-                                     gobject.TYPE_BOOLEAN,
-                                     ( )),
-        "confirm-overwrite" : ( gobject.SIGNAL_RUN_LAST,
-                                gobject.TYPE_BOOLEAN,
-                                (gobject.TYPE_STRING, )),
-        "settings-changed" : ( gobject.SIGNAL_RUN_LAST,
-                               gobject.TYPE_NONE,
-                               (  ))
+    __signals__ = {
+        "save-uri-requested" : None,
+        "confirm-overwrite" : ["location"],
+        "settings-changed" : None
         }
 
     __data_type__ = "project"
@@ -79,11 +74,11 @@ class Project(gobject.GObject, Serializable):
         uri : the uri of the project
         """
         gst.log("name:%s, uri:%s" % (name, uri))
-        gobject.GObject.__init__(self)
         self.name = name
         self.settings = None
         self.description = ""
         self.uri = uri
+        self.urichanged = False
         self.format = None
         self.sources = SourceList(self)
         self.timeline = None
@@ -103,7 +98,14 @@ class Project(gobject.GObject, Serializable):
             # should this return false?
             gst.warning("Already loaded !!!")
             return True
-        return self._load()
+        try:
+            res = self._load()
+        except:
+            gst.error("An Exception was raised during loading !")
+            traceback.print_exc()
+            res = False
+        finally:
+            return res
 
     def _load(self):
         """
@@ -112,9 +114,10 @@ class Project(gobject.GObject, Serializable):
         """
         gst.log("uri:%s" % self.uri)
         gst.debug("Creating timeline")
+        # FIXME : This should be discovered !
+        saveformat = "pickle"
         if self.uri and file_is_project(self.uri):
-            self.timeline = Timeline(self)
-            loader = ProjectSaver.newProjectSaver("pickle")
+            loader = ProjectSaver.newProjectSaver(saveformat)
             path = gst.uri_get_location(self.uri)
             fileobj = open(path, "r")
             try:
@@ -123,7 +126,11 @@ class Project(gobject.GObject, Serializable):
             except ProjectLoadError:
                 gst.error("Error while loading the project !!!")
                 return False
-            fileobj.close()
+            finally:
+                fileobj.close()
+            self.format = saveformat
+            self.urichanged = False
+            gst.debug("Done loading !")
             return True
         return False
 
@@ -140,28 +147,42 @@ class Project(gobject.GObject, Serializable):
         if uri_is_valid(self.uri):
             path = gst.uri_get_location(self.uri)
         else:
+            gst.warning("uri '%s' is invalid, aborting save" % self.uri)
             return False
+
         #TODO: a bit more sophisticated overwite detection
-        if os.path.exists(path):
-            if not self.emit("confirm-overwrite", self.uri):
+        if os.path.exists(path) and self.urichanged:
+            overwriteres = self.emit("confirm-overwrite", self.uri)
+            if overwriteres == False:
+                gst.log("aborting save because overwrite was denied")
                 return False
+
         try:
             fileobj = open(path, "w")
             loader = ProjectSaver.newProjectSaver(self.format)
             tree = self.toDataFormat()
             loader.saveToFile(tree, fileobj)
             self._dirty = False
+            self.urichanged = False
+            gst.log("Project file saved successfully !")
             return True
         except IOError:
             return False
 
     def save(self):
         """ Saves the project to the project's current file """
-        if not self.uri:
-            if self.emit("save-uri-requested"):
-                if not self.uri:
-                    return False
+        gst.log("saving...")
+        if self.uri:
+            return self._save()
+
+        gst.log("requesting for a uri to save to...")
+        saveres = self.emit("save-uri-requested")
+        if saveres == None or saveres == True:
+            gst.log("'save-uri-requested' returned True, self.uri:%s" % self.uri)
+            if self.uri:
                 return self._save()
+
+        gst.log("'save-uri-requested' returned False or uri wasn't set, aborting save")
         return False
 
     def saveAs(self):
@@ -177,12 +198,21 @@ class Project(gobject.GObject, Serializable):
         self.emit('settings-changed')
 
     def setUri(self, uri, format=None):
-        self.uri = uri
-        if not format:
-            path = gst.uri_get_location(uri)
-            ext = os.path.splitext(path)[1]
-            format = ProjectSaver.getFormat(ext)
-        self.format = format
+        """ Set the location to which this project will be stored """
+        gst.log("uri:%s, format:%s" % (uri, format))
+        if not self.uri == uri:
+            gst.log("updating self.uri, previously:%s" % self.uri)
+            self.uri = uri
+            self.urichanged = True
+
+        if not format or not self.format == format:
+            gst.log("updating save format, previously:%s" % self.format)
+            if not format:
+                path = gst.uri_get_location(uri)
+                ext = os.path.splitext(path)[1]
+                gst.log("Based on file extension, format is %s" % format)
+                format = ProjectSaver.getFormat(ext)
+            self.format = format
 
     def getSettings(self):
         """
@@ -250,11 +280,15 @@ class Project(gobject.GObject, Serializable):
     def fromDataFormat(self, obj):
         Serializable.fromDataFormat(self, obj)
         self.name = obj["name"]
-        self.settings = to_object_from_data_type(obj["settings"])
-        self.sources = to_object_from_data_type(obj["sources"])
-        self.timeline = to_object_from_data_type(obj["timeline"])
+        # calling this makes sure settigns-changed signal is emitted
+        self.setSettings(to_object_from_data_type(obj["settings"]))
+        # these objects already exist, so we initialize them from file
+        # to make sure UI catches signals
+        self.sources.fromDataFormat(obj["sources"])
+        self.timeline.fromDataFormat(obj["timeline"])
 
 def uri_is_valid(uri):
+    """ Checks if the given uri is a valid uri (of type file://) """
     return gst.uri_get_protocol(uri) == "file"
 
 def file_is_project(uri):
